<?php
include("slooze_local.php");
lang_init();
page_open(array("sess" => "Tof_Session",
				"auth" => "Tof_Auth")); 

$slooze = new MySlooze($auth->auth['uid']);
$render = new BasicRender($slooze);
$slooze->setRender($render);

$vars = $slooze->validateInputs();

$render->setBareTitle(_('Confirmation'));

require_once("render/form_elements.php");
require_once("render/header.php");

showTop($render);
$render->show('<div id="main">');
$render->show('<div class="normal">');
$render->show('<div class="confirm">');
$render->show(
	sprintf(_('You are about to %s. Are you sure you want to do this ?'),
			$vars['Message']));
showFormElementStart2(&$render,$vars['Target']);

// THIS IS OBVIOUSLY A SECURITY ISSUE !!!
eval('$confirmParams = '.$vars['Params'].';');
foreach($confirmParams as $name => $value) {
	showFormElementHidden($render,$name,$value);
}
showButton($render,'Confirm',_('Yes'));
showButton($render,'Abort',_('No'));
showFormElementEnd(&$render);
$render->show('</div>');// class="confirm"
$render->show('</div>');// class="normal"
$render->show('</div>');// id="main"

$render->flushPage();

page_close();
?>
